package com.ruoyi.tcZz.mapper;

import java.util.List;
import com.ruoyi.tcZz.domain.TcJgdw;
import org.apache.ibatis.annotations.Param;

/**
 * 监管单位Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
public interface TcJgdwMapper 
{
    /**
     * 查询监管单位
     * 
     * @param id 监管单位主键
     * @return 监管单位
     */
    public TcJgdw selectTcJgdwById(Long id);

    /**
     * 查询监管单位列表
     * 
     * @param tcJgdw 监管单位
     * @return 监管单位集合
     */
    public List<TcJgdw> selectTcJgdwList(TcJgdw tcJgdw);

    /**
     * 新增监管单位
     * 
     * @param tcJgdw 监管单位
     * @return 结果
     */
    public int insertTcJgdw(TcJgdw tcJgdw);

    /**
     * 修改监管单位
     * 
     * @param tcJgdw 监管单位
     * @return 结果
     */
    public int updateTcJgdw(TcJgdw tcJgdw);

    /**
     * 删除监管单位
     * 
     * @param id 监管单位主键
     * @return 结果
     */
    public int deleteTcJgdwById(Long id);

    /**
     * 批量删除监管单位
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcJgdwByIds(Long[] ids);

    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(@Param("isStatus") Integer isStatus, @Param("ids") List<String> ids);
}
